# django-temp-permissions

<!--
[![Test](https://github.com/k-tech-italy/django-temp-permissions/actions/workflows/test.yml/badge.svg)](https://github.com/k-tech-italy/django-temp-permissions/actions/workflows/test.yml)
[![Lint](https://github.com/k-tech-italy/django-temp-permissions/actions/workflows/lint.yml/badge.svg)](https://github.com/k-tech-italy/django-temp-permissions/actions/workflows/lint.yml)
[![Documentation](https://github.com/k-tech-italy/django-temp-permissions/actions/workflows/docs.yml/badge.svg)](https://github.com/k-tech-italy/django-temp-permissions/actions/workflows/docs.yml)
[![codecov](https://codecov.io/github/k-tech-italy/django-temp-permissions/graph/badge.svg?token=BNXEW4JAYF)](https://codecov.io/github/k-tech-italy/django-temp-permissions)
[![security: bandit](https://img.shields.io/badge/security-bandit-yellow.svg)](https://github.com/PyCQA/bandit)
[![Pypi](https://badge.fury.io/py/django-temp-permissions.svg)](https://badge.fury.io/py/django-temp-permissions)
[![coverage](https://codecov.io/github/k-tech-italy/django-temp-permissions/coverage.svg?branch=develop)](https://codecov.io/github/k-tech-italy/django-temp-permissions?branch=develop)
-->


django-temp-permissions is a Django app.

NOTE: Provide a more detailed description here.


## Dependencies

* Python 3.10 or later
* Django 4.2 or later


## Installation

* Install django-temp-permissions using your package manager of choice, e.g. Pip:
  ```bash
  pip install django-temp-permissions
  ```

* Add django-temp-permissions to `INSTALLED_APPS` in your `config/settings.py` file:
  ```python
  INSTALLED_APPS = (
      ...
      "django-temp-permissions",
      ...
  )
  ```

* Check that your configuration is valid:
  ```bash
  python manage.py check
  ```

## Bug reports and requests for enhancements

Please open an issue on the project's [issue tracker on GitHub](https://github.com/k-tech-italy/django-temp-permissions/issues).

## Contributing to the project

See the [contribution guide](CONTRIBUTING.md).

## Licensing

All rights reserved.
